from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Logic_Programmable = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'GAL16V8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GAL16V8'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'GAL PLD 16V8', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Logic_Programmable.kicad_sym\nGAL16V8\n\nGAL PLD 16V8', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='I1/CLK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I10/~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IO8',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='IO7',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='IO6',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='IO5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='IO4',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='I03',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='IO2',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='IO1',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='I9',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PAL16L8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PAL16L8'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'PAL PLD 16L8', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Logic_Programmable.kicad_sym\nPAL16L8\n\nPAL PLD 16L8', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I10',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IO8',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='IO7',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='IO6',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='IO5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='IO4',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='I03',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='IO2',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='IO1',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='I9',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PAL20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PAL20'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'logic programmable PAL', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Logic_Programmable.kicad_sym\nPAL20\n\nlogic programmable PAL', 'pins':[
            Pin(num='1',name='OD/CLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CLK/OD',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='LR/O3',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='A2/O2',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='A1/O1',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='A0/O0',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='O3/A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='O2/A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='O1/A0',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='O0/LR',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='I0',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='I1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='I2',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='I3',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='I4',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='I5',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='I6',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='I7',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PAL20L8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PAL20L8'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'PAL PLD 20L8', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Logic_Programmable.kicad_sym\nPAL20L8\n\nPAL PLD 20L8', 'pins':[
            Pin(num='12',name='GND',func=pin_types.PWRIN),
            Pin(num='24',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I10',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I11',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I13',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I14',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IO15',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='IO16',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='IO17',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='IO18',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='IO19',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='I020',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='IO21',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='IO22',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='I23',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='I9',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PAL20RS10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PAL20RS10'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'PAL PLD 20RS10', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Logic_Programmable.kicad_sym\nPAL20RS10\n\nPAL PLD 20RS10', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I9',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='O9',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='O8',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='O7',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='O6',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='O5',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='O4',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='O3',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='O2',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='O1',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='O0',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='I7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PAL24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PAL24'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'logic programmable PAL', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Logic_Programmable.kicad_sym\nPAL24\n\nlogic programmable PAL', 'pins':[
            Pin(num='1',name='OD/CLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='I8',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='I9',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='CLK/OD',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='LR/O4',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='A0/O3',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='A1/O2',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='A2/O1',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='NC/O0',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='O4/NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='I0',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='O3/A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='O2/A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='O1/A0',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='O0/LR',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='I1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='I2',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='I3',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='I4',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='I5',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='I6',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='I7',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Memory_Flash = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'28F400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'28F400'}), 'ref_prefix':'U', 'fplist':['Package_SO:PSOP-44_16.9x27.17mm_P1.27mm'], 'footprint':'Package_SO:PSOP-44_16.9x27.17mm_P1.27mm', 'keywords':'EEPROM FLASH 4MO', 'description':'', 'datasheet':'http://download.intel.com/design/archives/flash/docs/29045101.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\n28F400\n\nEEPROM FLASH 4MO', 'pins':[
            Pin(num='1',name='VPP',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='D8',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='D9',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='DU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='D10',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='D11',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='25',name='D12',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='27',name='D13',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='29',name='D14',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='31',name='A-1/D15',func=pin_types.TRISTATE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='BYTE',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='WE',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='PR',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'29F010-TSOP-SP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'29F010-TSOP-SP'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'EEPROM FLASH 128KO', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\n29F010-TSOP-SP\n\nEEPROM FLASH 128KO', 'pins':[
            Pin(num='1',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='24',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='27',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='29',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='WE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'29W040', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'29W040'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'EEPROM FLASH 512KO', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\n29W040\n\nEEPROM FLASH 512KO', 'pins':[
            Pin(num='1',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='24',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='27',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='29',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='WE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='A18',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AM29F400Bx-xxEx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AM29F400Bx-xxEx'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-I-48_18.4x12mm_P0.5mm'], 'footprint':'Package_SO:TSOP-I-48_18.4x12mm_P0.5mm', 'keywords':'FLASH 4Mbit', 'description':'', 'datasheet':'https://www.mouser.com/datasheet/2/380/AM29F400B_EOL_21505e8-9219.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAM29F400Bx-xxEx\n\nFLASH 4Mbit', 'pins':[
            Pin(num='5',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='RY/~{BY}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='DQ0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DQ8',func=pin_types.TRISTATE,unit=1),
            Pin(num='31',name='DQ1',func=pin_types.TRISTATE,unit=1),
            Pin(num='32',name='DQ9',func=pin_types.TRISTATE,unit=1),
            Pin(num='33',name='DQ2',func=pin_types.TRISTATE,unit=1),
            Pin(num='34',name='DQ10',func=pin_types.TRISTATE,unit=1),
            Pin(num='35',name='DQ3',func=pin_types.TRISTATE,unit=1),
            Pin(num='36',name='DQ11',func=pin_types.TRISTATE,unit=1),
            Pin(num='37',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='DQ4',func=pin_types.TRISTATE,unit=1),
            Pin(num='39',name='DQ12',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='DQ5',func=pin_types.TRISTATE,unit=1),
            Pin(num='41',name='DQ13',func=pin_types.TRISTATE,unit=1),
            Pin(num='42',name='DQ6',func=pin_types.TRISTATE,unit=1),
            Pin(num='43',name='DQ14',func=pin_types.TRISTATE,unit=1),
            Pin(num='44',name='DQ7',func=pin_types.TRISTATE,unit=1),
            Pin(num='45',name='DQ15/A-1',func=pin_types.TRISTATE,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='~{BYTE}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AM29F400Bx-xxSx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AM29F400Bx-xxSx'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-44_13.3x28.2mm_P1.27mm'], 'footprint':'Package_SO:SOP-44_13.3x28.2mm_P1.27mm', 'keywords':'FLASH 4Mbit', 'description':'', 'datasheet':'https://www.mouser.com/datasheet/2/380/AM29F400B_EOL_21505e8-9219.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAM29F400Bx-xxSx\n\nFLASH 4Mbit', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DQ0',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='DQ8',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='DQ1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='DQ9',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='DQ2',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='RY/~{BY}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='DQ10',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='DQ3',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='DQ11',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DQ4',func=pin_types.TRISTATE,unit=1),
            Pin(num='25',name='DQ12',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='DQ5',func=pin_types.TRISTATE,unit=1),
            Pin(num='27',name='DQ13',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='DQ6',func=pin_types.TRISTATE,unit=1),
            Pin(num='29',name='DQ14',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DQ7',func=pin_types.TRISTATE,unit=1),
            Pin(num='31',name='DQ15/A-1',func=pin_types.TRISTATE,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{BYTE}',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AM29PDL128G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AM29PDL128G'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAM29PDL128G\n\n', 'pins':[
            Pin(num='A1',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='A3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='RY/BY#',func=pin_types.OUTPUT,unit=1),
            Pin(num='A6',name='A21',func=pin_types.INPUT,unit=1),
            Pin(num='A7',name='WORD#',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='OE#',func=pin_types.INPUT,unit=1),
            Pin(num='B1',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='WP#',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='A20',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='CE#',func=pin_types.INPUT,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='WE#',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='DQ31/A-1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VIO',func=pin_types.INPUT,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='VIO',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='RST#',func=pin_types.INPUT,unit=1),
            Pin(num='E5',name='ACC',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VIO',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VIO',func=pin_types.INPUT,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='H5',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='J2',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='J5',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='J6',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='J7',name='A19',func=pin_types.INPUT,unit=1),
            Pin(num='J8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='K2',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='K3',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='K7',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='K8',name='A18',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT25DF041x-UxN-x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT25DF041x-UxN-x'}), 'ref_prefix':'U', 'fplist':['Package_CSP:WLCSP-8_1.58x1.63x0.35mm_Layout3x5_P0.35x0.4mm_Ball0.25mm_Pad0.25mm_NSMD'], 'footprint':'Package_CSP:WLCSP-8_1.58x1.63x0.35mm_Layout3x5_P0.35x0.4mm_Ball0.25mm_Pad0.25mm_NSMD', 'keywords':'SPI DSPI 4Mbit 1.65V', 'description':'', 'datasheet':'http://www.adestotech.com/wp-content/uploads/DS-AT25DF041B_040.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT25DF041x-UxN-x\n\nSPI DSPI 4Mbit 1.65V', 'pins':[
            Pin(num='A1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='~{HOLD}',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='SO/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='SI/IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='~{WP}',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT25SF081-SSHD-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT25SF081-SSHD-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'SPI DSPI QSPI 8Mbit 2.5V', 'description':'', 'datasheet':'https://www.adestotech.com/wp-content/uploads/DS-AT25SF081_045.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT25SF081-SSHD-X\n\nSPI DSPI QSPI 8Mbit 2.5V', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}/IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT25SF081-XMHD-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT25SF081-XMHD-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-8_4.4x3mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-8_4.4x3mm_P0.65mm', 'keywords':'SPI DSPI QSPI 8Mbit 2.5V', 'description':'', 'datasheet':'https://www.adestotech.com/wp-content/uploads/DS-AT25SF081_045.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT25SF081-XMHD-X\n\nSPI DSPI QSPI 8Mbit 2.5V', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}/IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT25SL321-U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT25SL321-U'}), 'ref_prefix':'U', 'fplist':['Package_CSP:WLCSP-8_1.551x2.284mm_P0.5mm'], 'footprint':'Package_CSP:WLCSP-8_1.551x2.284mm_P0.5mm', 'keywords':'SPI DSPI QSPI 32Mbit 1.7V', 'description':'', 'datasheet':'https://www.adestotech.com/wp-content/uploads/AT25SL321_112.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT25SL321-U\n\nSPI DSPI QSPI 32Mbit 1.7V', 'pins':[
            Pin(num='A1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='B1',name='~{HOLD}/IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO1/SO',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='~{WP}/IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='SI/IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT45DB161-JC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT45DB161-JC'}), 'ref_prefix':'U', 'fplist':['Package_LCC:PLCC-32_11.4x14.0mm_P1.27mm'], 'footprint':'Package_LCC:PLCC-32_11.4x14.0mm_P1.27mm', 'keywords':'Atmel DataFlash', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/doc0807.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT45DB161-JC\n\nAtmel DataFlash', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='RDY/~{BUSY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='~{WP}',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT45DB161-RC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT45DB161-RC'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_8.7x18.25mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_8.7x18.25mm_P1.27mm', 'keywords':'Atmel DataFlash', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/doc0807.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT45DB161-RC\n\nAtmel DataFlash', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='RDY/~{BUSY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{WP}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT45DB161-TC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT45DB161-TC'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-28_11.8x8mm_P0.55mm'], 'footprint':'Package_SO:TSOP-28_11.8x8mm_P0.55mm', 'keywords':'Atmel DataFlash', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/doc0807.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT45DB161-TC\n\nAtmel DataFlash', 'pins':[
            Pin(num='1',name='RDY/~{BUSY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SO',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{WP}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT45DB161D-SU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT45DB161D-SU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_5.275x5.275mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_5.275x5.275mm_P1.27mm', 'keywords':'Adesto Flash Memory DataFlash', 'description':'', 'datasheet':'https://www.adestotech.com/wp-content/uploads/doc3500.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT45DB161D-SU\n\nAdesto Flash Memory DataFlash', 'pins':[
            Pin(num='1',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{WP}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GD25D10CT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GD25D10CT'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOP-8_3.9x4.9mm_P1.27mm', 'keywords':'SPI DSPI QSPI 1Mbit 3.0V', 'description':'', 'datasheet':'http://www.elm-tech.com/en/products/spi-flash-memory/gd25d10/gd25d10.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nGD25D10CT\n\nSPI DSPI QSPI 1Mbit 3.0V', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='O1/SO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{WP}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS25WP256D-xM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS25WP256D-xM'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'SPI DSPI QSPI NOR 256Mbit 1.8V', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/IS25LP(WP)256D.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nIS25WP256D-xM\n\nSPI DSPI QSPI NOR 256Mbit 1.8V', 'pins':[
            Pin(num='1',name='~{HOLD}/IO3',func=pin_types.BIDIR),
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT),
            Pin(num='15',name='SI/IO0',func=pin_types.BIDIR),
            Pin(num='16',name='SCK',func=pin_types.INPUT),
            Pin(num='2',name='VCC',func=pin_types.PWRIN),
            Pin(num='3',name='~{RESET}/NC',func=pin_types.INPUT),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT),
            Pin(num='7',name='~{CE}',func=pin_types.INPUT),
            Pin(num='8',name='SO/IO1',func=pin_types.BIDIR),
            Pin(num='9',name='~{WP}/IO2',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'M25PX32-VMP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'M25PX32-VMP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-S-8-1EP_6x5mm_P1.27mm'], 'footprint':'Package_DFN_QFN:DFN-S-8-1EP_6x5mm_P1.27mm', 'keywords':'NOR Serial Flash Embedded Memory', 'description':'', 'datasheet':'https://www.mouser.de/datasheet/2/671/M25PX32-1282938.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nM25PX32-VMP\n\nNOR Serial Flash Embedded Memory', 'pins':[
            Pin(num='1',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{W}/V_{PP}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PAD/V_{SS}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'M25PX32-VMW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'M25PX32-VMW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'keywords':'NOR Serial Flash Embedded Memory', 'description':'', 'datasheet':'https://www.mouser.de/datasheet/2/671/M25PX32-1282938.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nM25PX32-VMW\n\nNOR Serial Flash Embedded Memory', 'pins':[
            Pin(num='1',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{W}/V_{PP}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V_{CC}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'M29W004', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'M29W004'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'EEPROM FLASH 512KO', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nM29W004\n\nEEPROM FLASH 512KO', 'pins':[
            Pin(num='1',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Rst/B',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Busy',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='27',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='33',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='34',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='35',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='36',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='WE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'M29W008', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'M29W008'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'EEPROM FLASH 1MO', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nM29W008\n\nEEPROM FLASH 1MO', 'pins':[
            Pin(num='1',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Rst/B',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Busy',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='27',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='33',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='34',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='35',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='36',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='A19',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='WE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MT25QUxxxxxx1xW7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MT25QUxxxxxx1xW7'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:W-PDFN-8-1EP_6x5mm_P1.27mm_EP3x3mm'], 'footprint':'Package_DFN_QFN:W-PDFN-8-1EP_6x5mm_P1.27mm_EP3x3mm', 'keywords':'Flash SPI DSPI QSPI 128Mbit 256Mbit 512Mbit 1Gbit 2Gbit 1.8V', 'description':'', 'datasheet':'https://media-www.micron.com/-/media/client/global/documents/products/data-sheet/nor-flash/serial-nor/mt25q/die-rev-a/mt25q_qljs_u_256_aba_0.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nMT25QUxxxxxx1xW7\n\nFlash SPI DSPI QSPI 128Mbit 256Mbit 512Mbit 1Gbit 2Gbit 1.8V', 'pins':[
            Pin(num='1',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{W}/DQ2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RESET}/DQ3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PAD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MX25L3233FM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MX25L3233FM'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'SPI 32Mbit', 'description':'', 'datasheet':'https://www.macronix.com/Lists/Datasheet/Attachments/8377/MX25L3233F,%203V,%2032Mb,%20v1.1.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nMX25L3233FM\n\nSPI 32Mbit', 'pins':[
            Pin(num='1',name='~{HOLD}/SIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='SI/SIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SO/SIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{WP}/SIO2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MX25L3233FZN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MX25L3233FZN'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4mm'], 'footprint':'Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4mm', 'keywords':'SPI 32Mbit', 'description':'', 'datasheet':'https://www.macronix.com/Lists/Datasheet/Attachments/8377/MX25L3233F,%203V,%2032Mb,%20v1.1.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nMX25L3233FZN\n\nSPI 32Mbit', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/SIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/SIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/SIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}/SIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='EP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MX25R3235FM1xx0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MX25R3235FM1xx0'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOP-8_3.9x4.9mm_P1.27mm', 'keywords':'SPI 32Mbit 1.65V-3.6V', 'description':'', 'datasheet':'http://www.macronix.com/Lists/Datasheet/Attachments/7534/MX25R3235F,%20Wide%20Range,%2032Mb,%20v1.6.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nMX25R3235FM1xx0\n\nSPI 32Mbit 1.65V-3.6V', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/SIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/SIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/SIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RESET}/SIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MX25R3235FM1xx1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MX25R3235FM1xx1'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOP-8_3.9x4.9mm_P1.27mm', 'keywords':'SPI 32Mbit 1.65V-3.6V', 'description':'', 'datasheet':'https://www.macronix.com/Lists/Datasheet/Attachments/8755/MX25R3235F,%20Wide%20Range,%2032Mb,%20v1.8.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nMX25R3235FM1xx1\n\nSPI 32Mbit 1.65V-3.6V', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/SIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/SIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/SIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}/SIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MX25R3235FM2xx0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MX25R3235FM2xx0'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-8_5.28x5.23mm_P1.27mm'], 'footprint':'Package_SO:SOP-8_5.28x5.23mm_P1.27mm', 'keywords':'SPI 32Mbit 1.65V-3.6V', 'description':'', 'datasheet':'http://www.macronix.com/Lists/Datasheet/Attachments/7534/MX25R3235F,%20Wide%20Range,%2032Mb,%20v1.6.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nMX25R3235FM2xx0\n\nSPI 32Mbit 1.65V-3.6V', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/SIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/SIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/SIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RESET}/SIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MX25R3235FM2xx1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MX25R3235FM2xx1'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-8_5.28x5.23mm_P1.27mm'], 'footprint':'Package_SO:SOP-8_5.28x5.23mm_P1.27mm', 'keywords':'SPI 32Mbit 1.65V-3.6V', 'description':'', 'datasheet':'http://www.macronix.com/Lists/Datasheet/Attachments/7534/MX25R3235F,%20Wide%20Range,%2032Mb,%20v1.6.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nMX25R3235FM2xx1\n\nSPI 32Mbit 1.65V-3.6V', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/SIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/SIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/SIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}/SIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MX25R3235FZNxx0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MX25R3235FZNxx0'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4mm'], 'footprint':'Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4mm', 'keywords':'SPI 32Mbit 1.65V-3.6V', 'description':'', 'datasheet':'http://www.macronix.com/Lists/Datasheet/Attachments/7534/MX25R3235F,%20Wide%20Range,%2032Mb,%20v1.6.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nMX25R3235FZNxx0\n\nSPI 32Mbit 1.65V-3.6V', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/SIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/SIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/SIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RESET}/SIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MX25R3235FZNxx1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MX25R3235FZNxx1'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4mm'], 'footprint':'Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4mm', 'keywords':'SPI 32Mbit 1.65V-3.6V', 'description':'', 'datasheet':'http://www.macronix.com/Lists/Datasheet/Attachments/7534/MX25R3235F,%20Wide%20Range,%2032Mb,%20v1.6.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nMX25R3235FZNxx1\n\nSPI 32Mbit 1.65V-3.6V', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/SIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/SIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/SIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}/SIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SST25VF080B-50-4x-S2Ax', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SST25VF080B-50-4x-S2Ax'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_5.275x5.275mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_5.275x5.275mm_P1.27mm', 'keywords':'flash memory spi', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005045C.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nSST25VF080B-50-4x-S2Ax\n\nflash memory spi', 'pins':[
            Pin(num='1',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{WP}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SST39SF010', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SST39SF010'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'128k flash rom', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/25022B.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nSST39SF010\n\n128k flash rom', 'pins':[
            Pin(num='16',name='GND',func=pin_types.PWRIN),
            Pin(num='32',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='NC',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='NC',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='PGM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SST39SF020', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SST39SF020'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'256k flash rom', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/25022B.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nSST39SF020\n\n256k flash rom', 'pins':[
            Pin(num='16',name='GND',func=pin_types.PWRIN),
            Pin(num='32',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='NC',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='PGM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SST39SF040', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SST39SF040'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'512k flash rom', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/25022B.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nSST39SF040\n\n512k flash rom', 'pins':[
            Pin(num='16',name='GND',func=pin_types.PWRIN),
            Pin(num='32',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='PGM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W25Q32JVSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W25Q32JVSS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_5.23x5.23mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_5.23x5.23mm_P1.27mm', 'keywords':'flash memory SPI', 'description':'', 'datasheet':'http://www.winbond.com/resource-files/w25q32jv%20revg%2003272018%20plus.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nW25Q32JVSS\n\nflash memory SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DO(IO1)',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DI(IO0)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W25Q32JVZP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W25Q32JVZP'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4.3mm'], 'footprint':'Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4.3mm', 'keywords':'flash memory SPI', 'description':'', 'datasheet':'http://www.winbond.com/resource-files/w25q32jv%20revg%2003272018%20plus.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nW25Q32JVZP\n\nflash memory SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DO(IO1)',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DI(IO0)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='EP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W25X40CLSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W25X40CLSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Memory Flash SPI', 'description':'', 'datasheet':'https://www.winbond.com/resource-files/W25X40CL_G%2020210505.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nW25X40CLSN\n\nMemory Flash SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DO(IO1)',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DI(IO0)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XTSD01G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XTSD01G'}), 'ref_prefix':'U', 'fplist':['Package_LGA:LGA-8_8x6mm_P1.27mm'], 'footprint':'Package_LGA:LGA-8_8x6mm_P1.27mm', 'keywords':'50MHz 1Gbit NAND FLASH SD2.0 ', 'description':'', 'datasheet':'https://datasheet.lcsc.com/lcsc/2005251034_XTX-XTSD08GLGEAG_C558840.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nXTSD01G\n\n50MHz 1Gbit NAND FLASH SD2.0 ', 'pins':[
            Pin(num='1',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SD3/~{CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CMD/DI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SD0/DO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AM29F400BB-90SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AM29F400BB-90SC'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-44_13.3x28.2mm_P1.27mm', 'Package_SO:SOP-44_13.3x28.2mm_P1.27mm'], 'footprint':'Package_SO:SOP-44_13.3x28.2mm_P1.27mm', 'keywords':'FLASH 4Mbit', 'description':'', 'datasheet':'https://www.mouser.com/datasheet/2/380/AM29F400B_EOL_21505e8-9219.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAM29F400BB-90SC\n\nFLASH 4Mbit', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DQ0',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='DQ8',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='DQ1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='DQ9',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='DQ2',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='RY/~{BY}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='DQ10',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='DQ3',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='DQ11',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DQ4',func=pin_types.TRISTATE,unit=1),
            Pin(num='25',name='DQ12',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='DQ5',func=pin_types.TRISTATE,unit=1),
            Pin(num='27',name='DQ13',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='DQ6',func=pin_types.TRISTATE,unit=1),
            Pin(num='29',name='DQ14',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DQ7',func=pin_types.TRISTATE,unit=1),
            Pin(num='31',name='DQ15/A-1',func=pin_types.TRISTATE,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{BYTE}',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT25SF081-SSHF-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT25SF081-SSHF-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'SPI DSPI QSPI 8Mbit 2.3V', 'description':'', 'datasheet':'https://www.adestotech.com/wp-content/uploads/DS-AT25SF081_045.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT25SF081-SSHF-X\n\nSPI DSPI QSPI 8Mbit 2.3V', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}/IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT25SF081-XMHF-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT25SF081-XMHF-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-8_4.4x3mm_P0.65mm', 'Package_SO:TSSOP-8_4.4x3mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-8_4.4x3mm_P0.65mm', 'keywords':'SPI DSPI QSPI 8Mbit 2.3V', 'description':'', 'datasheet':'https://www.adestotech.com/wp-content/uploads/DS-AT25SF081_045.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT25SF081-XMHF-X\n\nSPI DSPI QSPI 8Mbit 2.3V', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}/IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT45DB161B-RC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT45DB161B-RC'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_8.7x18.25mm_P1.27mm', 'Package_SO:SOIC-28W_8.7x18.25mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_8.7x18.25mm_P1.27mm', 'keywords':'Atmel DataFlash', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/doc2224.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT45DB161B-RC\n\nAtmel DataFlash', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='RDY/~{BUSY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{WP}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT45DB161B-RC-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT45DB161B-RC-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_8.7x18.25mm_P1.27mm', 'Package_SO:SOIC-28W_8.7x18.25mm_P1.27mm', 'Package_SO:SOIC-28W_8.7x18.25mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_8.7x18.25mm_P1.27mm', 'keywords':'Atmel DataFlash', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/doc2224.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT45DB161B-RC-2.5\n\nAtmel DataFlash', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='RDY/~{BUSY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{WP}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT45DB161B-TC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT45DB161B-TC'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-28_11.8x8mm_P0.55mm', 'Package_SO:TSOP-28_11.8x8mm_P0.55mm'], 'footprint':'Package_SO:TSOP-28_11.8x8mm_P0.55mm', 'keywords':'Atmel DataFlash', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/doc2224.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT45DB161B-TC\n\nAtmel DataFlash', 'pins':[
            Pin(num='1',name='RDY/~{BUSY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SO',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{WP}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT45DB161B-TC-2.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT45DB161B-TC-2.5'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-28_11.8x8mm_P0.55mm', 'Package_SO:TSOP-28_11.8x8mm_P0.55mm', 'Package_SO:TSOP-28_11.8x8mm_P0.55mm'], 'footprint':'Package_SO:TSOP-28_11.8x8mm_P0.55mm', 'keywords':'Atmel DataFlash', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/doc2224.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nAT45DB161B-TC-2.5\n\nAtmel DataFlash', 'pins':[
            Pin(num='1',name='RDY/~{BUSY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SO',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{WP}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GD25D05CT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GD25D05CT'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOP-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOP-8_3.9x4.9mm_P1.27mm', 'keywords':'SPI DSPI QSPI 512Kbit 3.0V', 'description':'', 'datasheet':'http://www.elm-tech.com/en/products/spi-flash-memory/gd25d10/gd25d10.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nGD25D05CT\n\nSPI DSPI QSPI 512Kbit 3.0V', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='O1/SO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{WP}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MX25L3233FM1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MX25L3233FM1'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-8_5.28x5.23mm_P1.27mm', 'Package_SO:SOP-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOP-8_5.28x5.23mm_P1.27mm', 'keywords':'SPI 32Mbit', 'description':'', 'datasheet':'https://www.macronix.com/Lists/Datasheet/Attachments/8377/MX25L3233F,%203V,%2032Mb,%20v1.1.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nMX25L3233FM1\n\nSPI 32Mbit', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/SIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/SIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/SIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}/SIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MX25L3233FM2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MX25L3233FM2'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-8_5.28x5.23mm_P1.27mm', 'Package_SO:SOP-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOP-8_5.28x5.23mm_P1.27mm'], 'footprint':'Package_SO:SOP-8_5.28x5.23mm_P1.27mm', 'keywords':'SPI 32Mbit', 'description':'', 'datasheet':'https://www.macronix.com/Lists/Datasheet/Attachments/8377/MX25L3233F,%203V,%2032Mb,%20v1.1.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nMX25L3233FM2\n\nSPI 32Mbit', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/SIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}/SIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/SIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}/SIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W25Q128JVE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W25Q128JVE'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_5.23x5.23mm_P1.27mm', 'Package_SON:WSON-8-1EP_8x6mm_P1.27mm_EP3.4x4.3mm'], 'footprint':'Package_SO:SOIC-8_5.23x5.23mm_P1.27mm', 'keywords':'flash memory SPI', 'description':'', 'datasheet':'https://www.winbond.com/resource-files/w25q128jv_dtr%20revc%2003272018%20plus.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nW25Q128JVE\n\nflash memory SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DO(IO1)',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DI(IO0)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W25Q128JVP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W25Q128JVP'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_5.23x5.23mm_P1.27mm', 'Package_SON:WSON-8-1EP_8x6mm_P1.27mm_EP3.4x4.3mm', 'Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4.3mm'], 'footprint':'Package_SO:SOIC-8_5.23x5.23mm_P1.27mm', 'keywords':'flash memory SPI', 'description':'', 'datasheet':'https://www.winbond.com/resource-files/w25q128jv_dtr%20revc%2003272018%20plus.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nW25Q128JVP\n\nflash memory SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DO(IO1)',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DI(IO0)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W25Q128JVS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W25Q128JVS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_5.23x5.23mm_P1.27mm', 'Package_SON:WSON-8-1EP_8x6mm_P1.27mm_EP3.4x4.3mm', 'Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4.3mm', 'Package_SO:SOIC-8_5.23x5.23mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_5.23x5.23mm_P1.27mm', 'keywords':'flash memory SPI QPI DTR', 'description':'', 'datasheet':'https://www.winbond.com/resource-files/w25q128jv_dtr%20revc%2003272018%20plus.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nW25Q128JVS\n\nflash memory SPI QPI DTR', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DO(IO1)',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DI(IO0)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W25Q16JVSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W25Q16JVSS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_5.23x5.23mm_P1.27mm', 'Package_SON:WSON-8-1EP_8x6mm_P1.27mm_EP3.4x4.3mm', 'Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4.3mm', 'Package_SO:SOIC-8_5.23x5.23mm_P1.27mm', 'Package_SO:SOIC-8_5.23x5.23mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_5.23x5.23mm_P1.27mm', 'keywords':'flash memory SPI', 'description':'', 'datasheet':'https://www.winbond.com/hq/support/documentation/levelOne.jsp?__locale=en&DocNo=DA00-W25Q16JV.1', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nW25Q16JVSS\n\nflash memory SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DO(IO1)',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DI(IO0)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W25X20CLSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W25X20CLSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Memory Flash SPI', 'description':'', 'datasheet':'https://www.winbond.com/resource-files/w25x20cl_revf%2020150806.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nW25X20CLSN\n\nMemory Flash SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DO(IO1)',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DI(IO0)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W25X20CLZP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W25X20CLZP'}), 'ref_prefix':'U12', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4.3mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Memory Flash SPI', 'description':'', 'datasheet':'https://www.winbond.com/resource-files/w25x20cl_revf%2020150806.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nW25X20CLZP\n\nMemory Flash SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DO(IO1)',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DI(IO0)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W25X40CLSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W25X40CLSS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4.3mm', 'Package_SO:SOIC-8_5.275x5.275mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Memory Flash SPI', 'description':'', 'datasheet':'https://www.winbond.com/resource-files/W25X40CL_G%2020210505.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nW25X40CLSS\n\nMemory Flash SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DO(IO1)',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DI(IO0)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W25X40CLSV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W25X40CLSV'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SON:WSON-8-1EP_6x5mm_P1.27mm_EP3.4x4.3mm', 'Package_SO:SOIC-8_5.275x5.275mm_P1.27mm', 'Package_SO:SOP-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Memory Flash SPI', 'description':'', 'datasheet':'https://www.winbond.com/resource-files/W25X40CL_G%2020210505.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nW25X40CLSV\n\nMemory Flash SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DO(IO1)',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{WP}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DI(IO0)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HOLD}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XTSD02G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XTSD02G'}), 'ref_prefix':'U', 'fplist':['Package_LGA:LGA-8_8x6mm_P1.27mm', 'Package_LGA:LGA-8_8x6mm_P1.27mm'], 'footprint':'Package_LGA:LGA-8_8x6mm_P1.27mm', 'keywords':'50MHz 2Gbit NAND FLASH SD2.0 ', 'description':'', 'datasheet':'https://datasheet.lcsc.com/lcsc/2005251034_XTX-XTSD08GLGEAG_C558840.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nXTSD02G\n\n50MHz 2Gbit NAND FLASH SD2.0 ', 'pins':[
            Pin(num='1',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SD3/~{CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CMD/DI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SD0/DO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XTSD04G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XTSD04G'}), 'ref_prefix':'U', 'fplist':['Package_LGA:LGA-8_8x6mm_P1.27mm', 'Package_LGA:LGA-8_8x6mm_P1.27mm', 'Package_LGA:LGA-8_8x6mm_P1.27mm'], 'footprint':'Package_LGA:LGA-8_8x6mm_P1.27mm', 'keywords':'50MHz 4Gbit NAND FLASH SD2.0 ', 'description':'', 'datasheet':'https://datasheet.lcsc.com/lcsc/2005251034_XTX-XTSD08GLGEAG_C558840.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nXTSD04G\n\n50MHz 4Gbit NAND FLASH SD2.0 ', 'pins':[
            Pin(num='1',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SD3/~{CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CMD/DI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SD0/DO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XTSD08G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XTSD08G'}), 'ref_prefix':'U', 'fplist':['Package_LGA:LGA-8_8x6mm_P1.27mm', 'Package_LGA:LGA-8_8x6mm_P1.27mm', 'Package_LGA:LGA-8_8x6mm_P1.27mm', 'Package_LGA:LGA-8_8x6mm_P1.27mm'], 'footprint':'Package_LGA:LGA-8_8x6mm_P1.27mm', 'keywords':'50MHz 8Gbit NAND FLASH SD2.0 ', 'description':'', 'datasheet':'https://datasheet.lcsc.com/lcsc/2005251034_XTX-XTSD08GLGEAG_C558840.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_Flash.kicad_sym\nXTSD08G\n\n50MHz 8Gbit NAND FLASH SD2.0 ', 'pins':[
            Pin(num='1',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SD3/~{CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CMD/DI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SD0/DO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Sensor_Audio = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'ICS-43434', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ICS-43434'}), 'ref_prefix':'MK', 'fplist':['Sensor_Audio:InvenSense_ICS-43434-6_3.5x2.65mm'], 'footprint':'Sensor_Audio:InvenSense_ICS-43434-6_3.5x2.65mm', 'keywords':'microphone MEMS 24bit I2S ICS-43434 TDK InvenSense', 'description':'', 'datasheet':'https://www.invensense.com/wp-content/uploads/2016/02/DS-000069-ICS-43434-v1.2.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Audio.kicad_sym\nICS-43434\n\nmicrophone MEMS 24bit I2S ICS-43434 TDK InvenSense', 'pins':[
            Pin(num='1',name='WS',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='LR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SD',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM69D120', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM69D120'}), 'ref_prefix':'MK', 'fplist':['Sensor_Audio:Infineon_PG-LLGA-5-1'], 'footprint':'Sensor_Audio:Infineon_PG-LLGA-5-1', 'keywords':'mems microphone', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-IM69D120-DS-v01_00-EN.pdf?fileId=5546d462602a9dc801607a0e41a01a2b', 'search_text':'/usr/share/kicad/symbols/Sensor_Audio.kicad_sym\nIM69D120\n\nmems microphone', 'pins':[
            Pin(num='1',name='DATA',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SELECT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM73A135V01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM73A135V01'}), 'ref_prefix':'MK', 'fplist':['Sensor_Audio:Infineon_PG-LLGA-5-2'], 'footprint':'Sensor_Audio:Infineon_PG-LLGA-5-2', 'keywords':'Microphone MEMS analog', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-IM73A135-DataSheet-v01_00-EN.pdf?fileId=8ac78c8c7f2a768a017fadec36b84500', 'search_text':'/usr/share/kicad/symbols/Sensor_Audio.kicad_sym\nIM73A135V01\n\nMicrophone MEMS analog', 'pins':[
            Pin(num='1',name='OUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT-',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MP45DT02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MP45DT02'}), 'ref_prefix':'MK', 'fplist':['Sensor_Audio:ST_HLGA-6_3.76x4.72mm_P1.65mm'], 'footprint':'Sensor_Audio:ST_HLGA-6_3.76x4.72mm_P1.65mm', 'keywords':'MEMS Microphone', 'description':'', 'datasheet':'http://www.st.com/st-web-ui/static/active/en/resource/technical/document/datasheet/DM00025467.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Audio.kicad_sym\nMP45DT02\n\nMEMS Microphone', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='LR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SPH0641LU4H-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SPH0641LU4H-1'}), 'ref_prefix':'MK', 'fplist':['Sensor_Audio:Knowles_LGA-5_3.5x2.65mm'], 'footprint':'Sensor_Audio:Knowles_LGA-5_3.5x2.65mm', 'keywords':'Microphone MEMS', 'description':'', 'datasheet':'https://www.knowles.com/docs/default-source/model-downloads/sph0641lu4h-1-revb.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Audio.kicad_sym\nSPH0641LU4H-1\n\nMicrophone MEMS', 'pins':[
            Pin(num='1',name='DATA',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='SEL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SPH0645LM4H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SPH0645LM4H'}), 'ref_prefix':'MK', 'fplist':['Sensor_Audio:Knowles_SPH0645LM4H-6_3.5x2.65mm'], 'footprint':'Sensor_Audio:Knowles_SPH0645LM4H-6_3.5x2.65mm', 'keywords':'microphone MEMS I2S 24bit Knowles SPH0645LM4H Crawford', 'description':'', 'datasheet':'https://www.knowles.com/docs/default-source/default-document-library/sph0645lm4h-1-datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Audio.kicad_sym\nSPH0645LM4H\n\nmicrophone MEMS I2S 24bit Knowles SPH0645LM4H Crawford', 'pins':[
            Pin(num='1',name='WS',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SEL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='BCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DATA',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SPM0687LR5H-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SPM0687LR5H-1'}), 'ref_prefix':'MK', 'fplist':['Sensor_Audio:Knowles_LGA-6_4.72x3.76mm'], 'footprint':'Sensor_Audio:Knowles_LGA-6_4.72x3.76mm', 'keywords':'Microphone MEMS Knowles Sisonic winfrey', 'description':'', 'datasheet':'https://www.knowles.com/docs/default-source/default-document-library/spm0687lr5h-1_winfrey_datasheet.pdf?Status=Master&sfvrsn=ac3971b1_0', 'search_text':'/usr/share/kicad/symbols/Sensor_Audio.kicad_sym\nSPM0687LR5H-1\n\nMicrophone MEMS Knowles Sisonic winfrey', 'pins':[
            Pin(num='1',name='OUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUT-',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM69D130', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM69D130'}), 'ref_prefix':'MK', 'fplist':['Sensor_Audio:Infineon_PG-LLGA-5-1', 'Sensor_Audio:Infineon_PG-LLGA-5-1'], 'footprint':'Sensor_Audio:Infineon_PG-LLGA-5-1', 'keywords':'mems microphone', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-IM69D130-DS-v01_00-EN.pdf?fileId=5546d462602a9dc801607a0e46511a2e', 'search_text':'/usr/share/kicad/symbols/Sensor_Audio.kicad_sym\nIM69D130\n\nmems microphone', 'pins':[
            Pin(num='1',name='DATA',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SELECT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])